==> huaweicloudsdklts-3.1.96-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/delete_search_criterias.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSearchCriterias:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'eps_id': 'str',
        'id': 'str'
    }

    attribute_map = {
        'eps_id': 'eps_id',
        'id': 'id'
    }

    def __init__(self, eps_id=None, id=None):
        """DeleteSearchCriterias

        The model defined in huaweicloud sdk

        :param eps_id: 企业项目id
        :type eps_id: str
        :param id: 快速查询id
        :type id: str
        """
        
        

        self._eps_id = None
        self._id = None
        self.discriminator = None

        if eps_id is not None:
            self.eps_id = eps_id
        self.id = id

    @property
    def eps_id(self):
        """Gets the eps_id of this DeleteSearchCriterias.

        企业项目id

        :return: The eps_id of this DeleteSearchCriterias.
        :rtype: str
        """
        return self._eps_id

    @eps_id.setter
    def eps_id(self, eps_id):
        """Sets the eps_id of this DeleteSearchCriterias.

        企业项目id

        :param eps_id: The eps_id of this DeleteSearchCriterias.
        :type eps_id: str
        """
        self._eps_id = eps_id

    @property
    def id(self):
        """Gets the id of this DeleteSearchCriterias.

        快速查询id

        :return: The id of this DeleteSearchCriterias.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeleteSearchCriterias.

        快速查询id

        :param id: The id of this DeleteSearchCriterias.
        :type id: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSearchCriterias):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklts-3.1.158-py2.py3-none-any.whl: huaweicloudsdklts/v2/model/delete_search_criterias.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSearchCriterias:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'eps_id': 'str',
        'id': 'str'
    }

    attribute_map = {
        'eps_id': 'eps_id',
        'id': 'id'
    }

    def __init__(self, eps_id=None, id=None):
        r"""DeleteSearchCriterias

        The model defined in huaweicloud sdk

        :param eps_id: 企业项目id
        :type eps_id: str
        :param id: 快速查询id
        :type id: str
        """
        
        

        self._eps_id = None
        self._id = None
        self.discriminator = None

        if eps_id is not None:
            self.eps_id = eps_id
        self.id = id

    @property
    def eps_id(self):
        r"""Gets the eps_id of this DeleteSearchCriterias.

        企业项目id

        :return: The eps_id of this DeleteSearchCriterias.
        :rtype: str
        """
        return self._eps_id

    @eps_id.setter
    def eps_id(self, eps_id):
        r"""Sets the eps_id of this DeleteSearchCriterias.

        企业项目id

        :param eps_id: The eps_id of this DeleteSearchCriterias.
        :type eps_id: str
        """
        self._eps_id = eps_id

    @property
    def id(self):
        r"""Gets the id of this DeleteSearchCriterias.

        快速查询id

        :return: The id of this DeleteSearchCriterias.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this DeleteSearchCriterias.

        快速查询id

        :param id: The id of this DeleteSearchCriterias.
        :type id: str
        """
        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSearchCriterias):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
